@@ -3,9 +3,9 @@ package RPi::WiringPi::LCD;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '1.00';
 
-use parent 'RPi::WiringPi::Core';
+use parent 'WiringPi::API';
 use RPi::WiringPi::Constant qw(:all);
 
 sub new {
@@ -51,7 +51,6 @@ sub cursor_blink {
 }
 sub send_cmd {
     my ($self, $cmd) = @_;
-    warn "\nlcdSendCommand() wiringPi function isn't documented!\n";
     $self->lcd_send_cmd($self->_fd, $cmd);
 }
 sub position {
@@ -82,19 +81,55 @@ __END__
 
 =head1 NAME
 
-RPi::WiringPi::LCD - Perl interface to Raspberry Pi LCD displays via the GPIO pins
+RPi::WiringPi::LCD - Perl interface to Raspberry Pi LCD displays via the GPIO
+pins
+
+=head1 SYNOPSIS
+
+    use RPi::WiringPi
+
+    my $pi = RPi::WiringPi->new;
+    my $lcd = $pi->lcd;
+
+    my %lcd_args = (
+        rows  => 2,     # number of display rows, 2 or 4
+        cols  => 16,    # number of display columns 16 or 20
+        bits  => 4,     # data width in bits, 4 or 8
+        rs    => 1,     # GPIO pin for the LCD RS pin
+        strb  => 2,     # GPIO pin for the LCD strobe (E) pin
+        d0    => 3,     #
+        ...             # d0-d3 GPIO pinout numbers
+        d3    => 6,     #
+        d4    => 7,     # set d4-d7 to all 0 (zero) if in 4-bit mode
+        ...             # otherwise, set them to their respective
+        d7    => 11,    # GPIO pins
+    );
+
+    # initialize the LCD screen
+
+    $lcd->init(%lcd_args);
+
+    my $perl_ver = '5.24.0';
+    my $name = 'stevieb';
+
+    $lcd->home; # row 0, col 0
+
+    $lcd->print("${name}'s RPi, on");
+
+    $lcd->position(0, 1); # row 2
+
+    $lcd->print("Perl $perl_ver...");
 
 =head1 DESCRIPTION
 
-WARNING: Until version 1.00 has been released, the API along with functionality
-may change at any time without any notice. If you happen to be testing with 
-this software and find something broken, please contact me.
+This module acts as an interface to typical 2 or 4 row, 16 or 20 column LCD
+screens when connected to a Raspberry Pi.
 
 =head1 METHODS
 
 =head2 new()
 
-Returns a new C<RPi::WiringPi::Core> object.
+Returns a new C<RPi::WiringPi::LCD> object.
 
 =head2 init(%args)
 
@@ -118,13 +153,16 @@ Parameters:
 Mandatory: All entries must have a value. If you're only using four (4) bit
 width, C<d4> through C<d7> must be set to C<0>.
 
+NOTE: In 4-bit mode, connect to pins C<d4> - C<d7> on the LCD. These pins act
+as C<d0> - C<d3> when not in 8-bit mode.
+
 =head2 home()
 
 Moves the LCD cursor to the home position (top row, leftmost column).
 
 =head2 clear()
 
-Clears the LCD display of all data.
+Clears the LCD display of all data, and return the cursor to the home position.
 
 =head2 display($state)
 
